<?php
/**
 * @name Administration-Views-Default-View.php
 * @version 0.8.1b
 * @package ZiMB Comment
 * @copyright Copyright (C) 2009 ZiMB LLC. All rights reserved.
 * @license GNU/GPL
 * 
 * ZiMB Comment provides Rich, AJAX style commenting with robust backend adminstrative tools
 * for your Joomla! website. 
 * 
 * view.php - This file provides the construction of the administration list view and various
 *            functionality that accompanies that page.  
 */

jimport( 'joomla.application.component.view' );

/**
 * @package MS Comment
 */
class DefaultComponentView extends JView
{
	var $page;
	var $pagesize;
	var $field;
	var $filter;
	var $db;
	var $pages;
	var $requestURI;
	/**
	 * Display the view
	 */
	function display($task, $page = 1, $pagesize = 20, $field = "", $filter = "")
	{
		// Set Basic Properties
		$baseURL = JURI::getPath();
		$this->page = $page;
		$this->pagesize = $pagesize;
		$this->field = $field;
		$this->filter = $filter;
		$this->db =& JFactory::getDBO();
		
		
		
		// Add Javascript
		$document = &JFactory::getDocument();
		$jsPath = 'components/com_zimbcomment/JavaScript/administrator.js';
		$document->addScript(JURI::base() . $jsPath);
		
		// Get total count of comments and derive number of pages based on page size.
		$query = "SELECT COUNT(*) as count FROM " . $this->db->nameQuote('#__zimbComment_Comment');
		$this->db->setQuery($query);
		$result = $this->db->loadObject();
		if ($pagesize != "All")
		{
			$this->pages = ceil($result->count / $this->pagesize);
		}
		else
		{
			$this->pages = 1;
		}
		
				
		//Set Document Title
		$document = & JFactory::getDocument();
		$document->setTitle("ZiMB Comment Administration");
		
		
    	// Determine task and process request.
		switch ($task)
		{
			case "admin":
				$this->_displayList();
				break;
			case "remove";
				$this->_deleteSelection();
				$this->_displayList();
				break;
			case "publish";
				$this->_publishSelection();
				$this->_displayList();
				break;
			case "unpublish";
				$this->_unpublishSelection();
				$this->_displayList();
				break;
			case "disable";
				$this->_disableList();
				break;
			case "returnCategories":
  				$this->_returnCategories();
  				break;
  			case "returnArticles":
  				$this->_returnArticles();
  				break;
  			case "saveDisables":
  				$this->_saveDisables();
  				break;
  			case "checkDisable":
  				$this->_checkDisable();
  				break;
  			case "CSS" : 
  				$this->_editCSS();
  				break;
  			case "saveCSS":
  				$this->_saveCSS();
  				break;
			default:
				break;
			
		}
  	}
  	/**
  	 * _getSQL - This function currently returns the SQL necessary to load one page of data
  	 *           for the displayList function.  Future functionality may include a more generic
  	 *           SQL builder for the entire application.
  	 *
  	 * @return string $sql
  	 */
  	function _getSQL()
  	{
  		$sql = "";
		$sql .= "SELECT * FROM " . $this->db->nameQuote('#__zimbComment_Comment');
  		// If header clicked to sort, add sort by this field.
		if ($this->field)
  		{
  			if ($this->field == "")
  			{
  				$sql .= " ORDER BY " . $this->db->nameQuote('saved');
  			}
  			else
  			{
  				$sql .= " ORDER BY " . $this->db->nameQuote($this->field);
  			}
  		}
		if ($this->pagesize != "All")
		{
			$sql .= " LIMIT " . ($this->page - 1) * $this->pagesize . ", " . $this->pagesize;
		}
		return $sql;
  	}
  	/**
  	 * _displayList - displays one page of data with all accompanying controls to the 
  	 *                admin user.  Future versions will expand functionality to include
  	 *                sorting and filters.  
  	 */
   	function _displayList()
  	{
  		//////////////////////////////////////
  		// Get list of comments to display. //
  		//////////////////////////////////////
  		$this->db->setQuery($this->_getSQL());
		$results = $this->db->loadObjectList();
		
		$request = JURI::current() . "?option=com_zimbcomment";
		/////////////////////////////////////////////////
		// adminForm form with necessary hidden fields.//
		/////////////////////////////////////////////////  
		echo '<form action="' . $request . '" method="post" name="adminForm" id="adminForm">';
		// Hidden Inputs
		echo '<input type="hidden" id="task" name="task" value ="' . $task . '">';
		echo '<input type="hidden" id="boxchecked" name="boxchecked" value = "0">';
		echo '<input type="hidden" id="checkedlist" name="checkedlist">';
		echo '<input type="hidden" id="pagesize" name="pagesize" value="' . $this->pagesize . '">';
		
		////////////////////////////////
		// Beginning of display table.//
		////////////////////////////////
		echo '<table class="adminlist" cellspacing="1">';
		
		///////////////////////////////////
		//       Header Information      //
		///////////////////////////////////
		// TODO: Make headers clickable to sort by column.  TARGET: v.6.0a
		echo '<thead><tr>';
		$this->field = "id";
		$url = "index.php?option=com_zimbcomment&task=administer&page=" .$this->page.  "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
		echo '<th width="5"><a href="' . $url . '">#</a></th>';
		echo '<th width="5"><input type="checkbox" name="toggle" value="" onclick="checkall(this.checked);"></th>';
		$this->field = "articleId";
		$url = "index.php?option=com_zimbcomment&task=administer&page=" .$this->page.   "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
		echo '<th><a href="' . $url . '">Article Name</a></th>';
		$this->field = "handle";
		$url = "index.php?option=com_zimbcomment&task=administer&page=" .$this->page.   "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
		echo '<th class="title"><a href="' . $url . '">Username</a></th>';
		echo '<th>E-mail</th>';
		echo '<th>Website</th>';
		echo '<th>Published</th>';
		$this->field = "saved";
		$url = "index.php?option=com_zimbcomment&task=administer&page=" .$this->page.   "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
		echo '<th><a href="' . $url . '">Time</a></th>';
		echo '<th>IP Address</th>';
		echo '<th>Content</th>';
		echo '</tr></thead>';
		
		/////////////////////////////////////
		//         Footer Information      //
		/////////////////////////////////////
		echo '<tfoot><tr>';
		echo '<tr>';
		echo '<td colspan="15">';
		echo '<del class="container"><div class="pagination">';
		echo '<div class="limit">Display #<select name="limit" id="limit" class="inputbox" size="1" onchange="submitbutton(false);">';
		
		$values = array('10', '15', '20', '25', '30', '50', '100', 'All');
		foreach ($values as $value)
		{
			echo '<option value="' . $value . '"';
			if ($value == $this->pagesize)
			{
				echo ' selected="selected"';	
			}
			echo '>' . $value . '</option>';
		}		
		echo '</select></div>';
		
		if ($this->page > 1)
		{
			$offon = "";
			$prev = $this->page - 1;
			$start = 1;
			$url = "index.php?option=com_zimbcomment&task=administer&page=" . $prev . "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
			$starthref = '<a href="' . $url . '">';
			$url = "index.php?option=com_zimbcomment&task=administer&page=" . $start . "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
			$prevhref = '<a href="' . $url . '">';
			$hreftail = '</a>';
		}
		else
		{
			$offon = " off";
			$starthref = '<span>';
			$prevhref = '<span>';
			$hreftail = '</span>';
		}
		echo '<div class="button2-right' . $offon . '"><div class="start">'. $starthref . 'Start' . $hreftail . '</div></div>';
		echo '<div class="button2-right' . $offon . '"><div class="prev">' . $prevhref . 'Prev' . $hreftail . '</div></div>';
		echo '<div class="button2-left"><div class="page">';
		for ($i=1; $i <= $this->pages; $i++)
		{
			if ($this->page == $i)
			{
				echo "<span>" . $i . "</span>";
			}
			else
			{
				$url = "index.php?option=com_zimbcomment&task=administer&page=" . $i . "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
				echo '<a href="' . $url . '" title="' . $i . '">' . $i . '</a>';
			}
		}
		echo '</div></div>';
		if ($this->pages > $this->page)
		{
			$offon = "";
			$end = $this->pages;
			$next = $this->page + 1;
			$url = "index.php?option=com_zimbcomment&task=administer&page=" . $next . "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
			$nexthref = '<a href="' . $url . '">';
			$url = "index.php?option=com_zimbcomment&task=administer&page=" . $end . "&pagesize=" . $this->pagesize . "&field=" . $this->field . "&filter=" . $this->filter;
			$endhref = '<a href="' . $url . '">';
			
			$hreftail = '</a>';
					
		}
		else
		{
			$offon = " off";
			$nexthref = "<span>";
			$endhref = "<span>";
			$hreftail = "</span>";
		}
		echo '<div class="button2-left' . $offon . '"><div class="next">' . $nexthref . 'Next' . $hreftail . '</div></div>';
		echo '<div class="button2-left' . $offon . '"><div class="end">' . $endhref . 'End' . $hreftail . '</div></div>';
			
		echo '<div class="limit">Page' . $this->page . ' of ' . $this->pages . '</div>';
		echo '<input type="hidden" name="limitstart" value="0" /></div></del>';
		echo '</td>';
		echo '</tr></tfoot>';
		echo '<tbody>';
		$rowstyle = 0;
		$path = str_replace("/administrator", "", JURI::base()) . "index.php?";
		if ($results)
		{
			foreach ($results as $result)
			{
				echo '<tr class="row' . $rowstyle . '">';
				echo '<td>';
				echo $result->id;
				echo '</td>';
				echo '<td>';
				echo '<input type="checkbox" name="checked' . $result->id . '" onclick="checkbox();">';
				echo '</td>';
				echo '<td>';
				$query = "SELECT " . $this->db->nameQuote('title') . " from " . $this->db->nameQuote('#__content') . " WHERE " . $this->db->nameQuote('id') . " = " . $result->articleId;
	   			$this->db->setQuery($query);
	   			$articleName = $this->db->loadResult();
				echo '<a href="' . $path . 'option=com_content&view=article&id=' . $result->articleId . '" target="_blank">' . $articleName . "</a>";
				echo '</td>';
				echo '<td>';
				if ($result->isUser)
	   			{
	   				//TODO: Get from DBO from USER table and get that handle.  Don't feel like looking up the table
	   				// right now.  7-11-08.
	   				$query = "SELECT " . $this->db->nameQuote('username') . " from " . $this->db->nameQuote('#__users') . " WHERE " . $this->db->nameQuote('id') . " = " . $result->handle;
	   				$this->db->setQuery($query);
	   				$handle = $this->db->loadResult();
	   			}
	   			else
	   			{
	   				$handle = $result->handle;
	   			}
	   			echo $handle;
				echo '</td>';
				echo '<td>';
				echo '<a href="mailto:' . $result->email . '">' . $result->email . '</a>';
				echo '</td>';
				echo '<td>';
				echo '<a href="' . $result->website . '">' . $result->website . '</a>'; 
				echo '</td>';
				echo '<td>';
				if ($result->published)
				{
					echo "Yes";
				}
				else
				{
					echo "No";
				}
				echo '</td>';
				echo '<td>';
				echo $result->saved;
				echo '</td>';
				echo '<td>';
				echo $result->ipAddress;
				echo '</td>';
				echo '<td>';
				echo $result->content;
				echo '</td>';
				if ($rowstyle == 1)
				{
					$rowstyle = 0;
				}
				else
				{
					$rowstyle = 1;
				}
				echo '</tr>';
			}	
		}
				
		echo '</tbody>';
		echo '</table>';
		echo '</form>';
  	}
  	function _deleteSelection()
  	{
  		$items = explode("|", $_POST['checkedlist']);
  		$deletedItems = new ArrayObject();
  		if ($items)
  		{
  			if (is_array($items))
  			{
  				foreach($items as $item)
  				{
  				if (strlen($item) > 0)
  					{
  						$deletedItems->append($item);
  					}
  				}
  			}
  			else
  			{
  				$items = str_replace("|", "", $items);
  				$deletedItems->append($items);	
  			}
  			$sql = "DELETE FROM " . $this->db->nameQuote('#__zimbComment_Comment') . " WHERE " . $this->db->nameQuote('id') . " IN (";
  			$count = 0;
  			foreach ($deletedItems as $item)
  			{
  				if ($count == 0)
  				{
  					$sql .= $item;
  					$count = 1;
  				}
  				else
  				{
  					$sql .= ", " . $item;
  				}
  			}
  			$sql .= ")";
  			$this->db->execute($sql);
  		}
  		
  	}
  	function _publishSelection()
  	{
  		$items = explode("|", $_POST['checkedlist']);
  		$publishedItems = new ArrayObject();
  		if ($items)
  		{
  			if (is_array($items))
  			{
  				foreach($items as $item)
  				{
  				if (strlen($item) > 0)
  					{
  						$publishedItems->append($item);
  					}
  				}
  			}
  			else
  			{
  				$items = str_replace("|", "", $items);
  				$publishedItems->append($items);	
  			}
  			$sql = "UPDATE " . $this->db->nameQuote('#__zimbComment_Comment') . " SET " . $this->db->nameQuote('published') . " = 1 WHERE " . $this->db->nameQuote('id') . " IN (";
  			
  			$count = 0;
  			foreach ($publishedItems as $item)
  			{
  				if ($count == 0)
  				{
  					$sql .= $item;
  					$count = 1;
  				}
  				else
  				{
  					$sql .= ", " . $item;
  				}
  			}
  			$sql .= ")";
  			$this->db->execute($sql);
  		}
  		
  	}
  	function _unpublishSelection()
  	{
  	$items = explode("|", $_POST['checkedlist']);
  		$unpublishedItems = new ArrayObject();
  		if ($items)
  		{
  			if (is_array($items))
  			{
  				foreach($items as $item)
  				{
  					if (strlen($item) > 0)
  					{
  						$unpublishedItems->append($item);
  					}
  					
  				}
  			}
  			else
  			{
  				$items = str_replace("|", "", $items);
  				$unpublishedItems->append($items);	
  			}
  			$sql = "UPDATE " . $this->db->nameQuote('#__zimbComment_Comment') . " SET " . $this->db->nameQuote('published') . " = 0 WHERE " . $this->db->nameQuote('id') . " IN (";
  			
  			$count = 0;
  			foreach ($unpublishedItems as $item)
  			{
  				if ($count == 0)
  				{
  					$sql .= $item;
  					$count = 1;
  				}
  				else
  				{
  					$sql .= ", " . $item;
  				}
  			}
  			$sql .= ")";
  			$this->db->execute($sql);
  		}
  	}
	function _disableList()
	{
			// Get List of Sections
			$this->db =& JFactory::getDBO();
			$sql = "SELECT id, title FROM #__sections";
			$this->db->setQuery($sql);
			$results = $this->db->loadObjectList();
			$path = JURI::base() . "index2.php?option=com_zimbcomment";
			
			
			
			echo '<select name="section" id="section" onchange="loadCategories(' . "'" . 'category' . "'" . ', this.options[this.selectedIndex].value, ' . "'" . $path . "'" . ');checkDisable(' . "'" . 'section' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'sectionButton' . "'" . ');">';
			echo '<option value=""></option>';
			foreach ($results as $result)
			{
				echo '<option value="' . $result->id . '">' . $result->title . '</option>';
			}
			
			
			echo '</select>';
			echo '<input type="button" value="Disable" id="sectionButton" onclick="saveDisable(' . "'" . 'section' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'sectionButton' . "'" . ');"><br>';
			
			// Empty Category/Article Select Controls
			echo '<select name="category" id="category" onchange="loadArticles(' . "'" . 'article' . "'" . ', this.options[this.selectedIndex].value, ' . "'" . $path . "'" . ');checkDisable(' . "'" . 'category' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'categoryButton' . "'" . ');"></select>';
			echo '<input type="button" value="Disable" id="categoryButton" onclick="saveDisable(' . "'" . 'category' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'categoryButton' . "'" . ');"><br>';
			echo '<select name="article" id="article" onchange="checkDisable(' . "'" . 'article' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'articleButton' . "'" . ');"></select>';
			echo '<input type="button" value="Disable" id="articleButton" onclick="saveDisable(' . "'" . 'article' . "'" . ', ' . "'" . $path . "'" . ', ' . "'" . 'articleButton' . "'" . ');"><br>';
			
	}
	function _returnCategories()
	{
		$sectionId = JRequest::getVar('sectionId', -1);
		$this->db = & JFactory::getDBO();
		$sql = "SELECT id, title FROM #__categories where section = " . $sectionId ;
		$this->db->setQuery($sql);
		$results = $this->db->loadObjectList();
		$path = JURI::base() . "index2.php?option=com_zimbcomment";
		echo '<option value=""></option>';
		foreach ($results as $result)
		{
			echo '<option value="' . $result->id . '">' . $result->title . '</option>';
		}
	}
	function _returnArticles()
	{
		$categoryId = JRequest::getVar('categoryId', -1);
		$this->db = & JFactory::getDBO();
		$sql = "SELECT id, title FROM #__content where catid = " . $categoryId;
		$this->db->setQuery($sql);
		$results = $this->db->loadObjectList();
		$path = JURI::base() . "index2.php?option=com_zimbcomment";
		echo '<option value=""></option>';
		foreach ($results as $result)
		{
			echo '<option value="' . $result->id . '">' . $result->title . '</option>';
		}
	}
	function _saveDisables()
	{
		$type = JRequest::getVar('type', "");
		$targetId = JRequest::getVar('targetId', -1);
		$this->db = & JFactory::getDBO();
		$sql = "SELECT id FROM #__zimbComment_Disabled where type='" . $type . "' and target_id = " . $targetId;
		$this->db->setQuery($sql);
		
		$found = $this->db->loadResult();
	
		if ($found)
		{
			// Delete record.
			$sql = "DELETE FROM #__zimbComment_Disabled where id=" . $found;
			$this->db->execute($sql);
			echo "Disable";
		}
		else
		{
			// Write Record
			
			$sql = "INSERT INTO #__zimbComment_Disabled (target_id, type) values (" . $targetId . ", '" . $type . "')";
			$this->db->execute($sql);
			echo "Enable";
		}
	
		echo "";
	}
	
	function _checkDisable()
	{
		$type = JRequest::getVar('type', "");
		$targetId = JRequest::getVar('targetId', -1);
		$this->db = & JFactory::getDBO();
		$sql = "SELECT id FROM #__zimbComment_Disabled where type='" . $type . "' and target_id = " . $targetId;
		$this->db->setQuery($sql);
		
		$found = $this->db->loadResult();
	
		if ($found)
		{
			echo "Enable";
		}
		else
		{
			echo "Disable";
		}
	
		echo "";
	}
	function _editCSS()
	{
		$path = JPATH_COMPONENT_ADMINISTRATOR;
		$file = fopen($path . "/zimbComment.css", 'r+');
		$target = JURI::base() . "index2.php?option=com_zimbcomment&task=saveCSS";
		$CSS = fread($file, filesize($path . "/zimbComment.css"));
		//$theData = str_replace("\n", "<BR>", $CSS);
		echo '<form id="css" action="' . $target . '" method="post">';
		echo '<textarea id="csstext" rows="30" cols="100" onchange="css.value = this.value;">';
		echo $CSS;
		echo '</textarea><br>';
		echo '<input type="hidden" value="' . $CSS . '" id="css" name="css">';
		echo '<input type="submit" value="Save CSS" id="saveCSS">';
		echo '</form>';
	}
	function _saveCSS()
	{
		$CSS = JRequest::getVar('css', -1);
		echo "CSS Saved";
		$path = JPATH_COMPONENT_ADMINISTRATOR;
		$file = fopen($path . "/zimbComment.css", 'w+');
		fwrite($file, $CSS);
		fclose($file);
	}
}
?>